@@ -392,11 +392,6 @@ fn main() {
         IpAddr::V4(Ipv4Addr::new(0, 0, 0, 0)),
         faucet_port,
     ));
-    // JIT not supported on the BPF VM in Windows currently: https://github.com/solana-labs/rbpf/issues/217
-    #[cfg(target_family = "windows")]
-    let bpf_jit = false;
-    #[cfg(not(target_family = "windows"))]
-    let bpf_jit = !matches.is_present("no_bpf_jit");
 
     let mut programs = vec![];
     if let Some(values) = matches.values_of("bpf_program") {
@@ -511,6 +506,7 @@ fn main() {
 
     let mut genesis = TestValidatorGenesis::default();
     genesis.max_ledger_shreds = value_of(&matches, "limit_ledger_size");
+    genesis.max_genesis_archive_unpacked_size = Some(u64::MAX);
 
     admin_rpc_service::run(
         &ledger_path,
@@ -550,7 +546,7 @@ fn main() {
             faucet_addr,
             ..JsonRpcConfig::default()
         })
-        .bpf_jit(bpf_jit)
+        .bpf_jit(!matches.is_present("no_bpf_jit"))
         .rpc_port(rpc_port)
         .add_programs_with_path(&programs);
 
